#27 May 2019
#Redone analysis for major revisions through RSOS for LHTE of Daphnia in high and low phosphorus food treatments

####################
#import data. first set the working directory using Session->set working directory->choose directory
life <- read.csv("Fall2013_Daphnia lifehistorytraits_R.csv", header = TRUE)

#####################
#format data: Block, Clone, Mother need to be using as.factor() when used.
#Remove D. lumholtzi
life <-life[1:221,]
life$Species<-factor(life$Species)
#Remove rows where individuals are less than 5 days old (they don't have an Age.end)
life<-life[complete.cases(life[,10]),]

#Remove rows where individuals are male
life<-life[!(life$Sex == 'm'),]

######################
#find out how survivorship is distributed by species and treatment
aggregate(life, by = list(life$Species, life$Treatment), function(x) {sum(is.na(x))})

#make matrix for chisquare contingency test. we are testing whether treatment is independent of species survivorship
chimatrix <- matrix(data = c(19, 19, 17, 20, 20, 19, 19, 19), nrow = 4, ncol = 2)
#run chisq contingency
chisq.test(chimatrix)

#################################
#MANOVA test was done in SPSS. I was having trouble with covariates and SS type (I instead of III) in R
#correlation matrix on response variables to check for colinearity.
cormatrix <-matrix(data = cbind(life$Length.maturation, life$Age.maturation, life$Length.end, life$Mean.clutch.length, life$Mean.clutch.size, life$Number.clutches), ncol = 6)
cor(na.omit(cormatrix), method = "pearson")
library("Hmisc")
rcorr(na.omit(cormatrix), type = "pearson")

#####################################
#Run a two-way ANOVA on cohen's d effect sizes. Moved to supplements. There were no significant differences between species or trait type (growth vs. size) on effect size
table <-read.csv("effectsizedata.csv", header = TRUE)
tableaov<-aov(Effect~Species*Treatment, data = table)
summary(tableaov)

########################################
#Do multiple linear regressions per trait determine species-level responses to treatment.Adjust alpha level using Bonferroni because why not be conservative in this case?
#Run fits
afit <- lm(Age.maturation~Treatment*Species, data = life)
bfit <- lm(Length.maturation~Treatment*Species, data = life)
cfit <- lm(Length.end~Treatment*Species, data = life)
dfit <- lm(Mean.clutch.length ~Treatment*Species, data = life)
efit <- lm(Mean.clutch.size ~Treatment*Species, data = life)
ffit <- lm(Number.clutches ~Treatment*Species, data = life)

summary(afit)
summary(bfit)
summary(cfit)
summary(dfit)
summary(efit)
summary(ffit)

########################################
#calculate COVs in R for ease of access in making a table if needed: by species and treatment for every trait
aggregate(cbind(life$Start.length, life$Length.maturation, life$Length.end, life$Mean.clutch.length, life$Mean.clutch.size,life$Number.clutches),
          by= list(life$Species, life$Treatment), 
          function(x) {sd(x, na.rm = TRUE)/mean(x, na.rm = TRUE)*100}
          )
#Calculate COV in R per species to directly correlate to species-level response for every trait
cov <- aggregate(cbind(life$Start.length, life$Length.maturation, life$Length.end, life$Mean.clutch.length, life$Mean.clutch.size,life$Number.clutches),
                 by= list(life$Species), 
                 function(x) {sd(x, na.rm = TRUE)/mean(x, na.rm = TRUE)*100}
)
#Calculate species-level response in R for ease of access in potentially making a table by species and treatment for every trait
aggregate(cbind(life$Start.length, life$Length.maturation, life$Length.end, life$Mean.clutch.length, life$Mean.clutch.size,life$Number.clutches),
          by= list(life$Species, life$Treatment), 
          function(x) {log(mean(x, na.rm = TRUE))}
          )
#From output, I did the subtractions for response in excel. Named this file reactionnorm.csv 
#I also moved the cov data into the file, because I need to be able to run rcorr on more than 4 data points.
#Saved in reactionnorm.csv
response <- read.csv("reactionnorm.csv", header = TRUE)
#remove calculated values in rows below row 24
response<-response[1:24,]
#################################################################
#Run a correlation analysis between the two matrices (cov and response)
cor.test(response$Response,response$Cov, method = "pearson")

#################################################
#PLOTTING LINES OF CODE
#Plotting covs and species-level response rates.(figure 2)
corrplot <- ggplot(response, aes(Cov, Response, color = factor(Trait, labels = c("Length at maturation", "Age at Maturation", "End length", "Mean clutch length", "Mean clutch size", "Number of clutches")), shape = Group))+
  geom_point()+labs(x="Coefficients of Variance (%)", y = "Species-level response", color = "Trait")+theme_bw()
corrplot

#Plotting linear regressions (figure 1))
library(ggpubr)
a<-ggplot(life, aes(Treatment, Length.maturation))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y="Length at maturation (um)",x="")
b <-ggplot(life, aes(Treatment, Age.maturation))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y="Age at maturation (days)",x="")
c<-ggplot(life, aes(Treatment, Length.end))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y = "End length (um)", x="")
d<-ggplot(life, aes(Treatment, Mean.clutch.length))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y="Mean clutch length (um)",x="")
e<-ggplot(life, aes(Treatment, Mean.clutch.size))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y="Mean clutch size",x="")
f<-ggplot(life, aes(Treatment, Number.clutches))+geom_boxplot()+facet_wrap(~Species, nrow = 4)+labs(y="Number of clutches",x="")
ggarrange(a,b,c,d,e,f,nrow =1, ncol = 6, labels = c("A", "B", "C", "D", "E", "F"))

#####################################
#Citations
citation()
citation("dplyr")
citation("ggplot2")
citation("ggpubr")
citation("Hmisc")